@@ -17,18 +17,18 @@ describe 'Service Bus Management Client' do
 
   it 'should create list and delete namespace' do
     namespace_name = "smaple34566"
-    namespace_parameters = Azure::ARM::ServiceBus::Models::NamespaceCreateOrUpdateParameters.new
+    namespace_parameters = Azure::ARM::ServiceBus::Models::SBNamespace.new
     namespace_parameters.location = 'westus'
 
     # Create new namespace
-    namespace_resource = @service_bus_client.namespaces.create_or_update(@resource_group.name, namespace_name, namespace_parameters)
-    expect(namespace_resource).not_to be_nil
-    expect(namespace_resource).to be_a(Azure::ARM::ServiceBus::Models::NamespaceResource)
-    expect(namespace_resource.name).to eq(namespace_name)
-    expect(namespace_resource.provisioning_state).to eq("Succeeded")
+    namespace = @service_bus_client.namespaces.create_or_update(@resource_group.name, namespace_name, namespace_parameters)
+    expect(namespace).not_to be_nil
+    expect(namespace).to be_a(Azure::ARM::ServiceBus::Models::SBNamespace)
+    expect(namespace.name).to eq(namespace_name)
+    expect(namespace.provisioning_state).to eq("Succeeded")
 
     # List namespace
-    namespaces = @service_bus_client.namespaces.list_by_subscription()
+    namespaces = @service_bus_client.namespaces.list
     expect(namespaces).not_to be_nil
     expect(namespaces).to be_a(Array)
     expect(namespaces.length).to be(1)
